import requests
import re
import argparse
import csv
from . import csv_import, bitly_import, link_expand

shortcm_subparsers = [csv_import, bitly_import, link_expand]

def chunks(l, n):
    """Yield successive n-sized chunks from l."""
    for i in range(0, len(l), n):
        yield l[i:i + n]

def import_csv(filename, secret_key, domain, original_url_column, path_column, title_column, created_at_column):
    with open(filename) as f:
        csv_reader = csv.reader(f)
        lines = [line for line in csv_reader]
        link_chunks = chunks(lines, 1000)
        for idx, chunk in enumerate(link_chunks):
            r = requests.post('https://api.short.cm/links/bulk', headers={
                'Authorization': secret_key,
            }, json=dict(
                domain=domain,
                links=[
                    dict(
                        originalURL=chunk_item[original_url_column],
                        path=re.sub('https?://[^/]+/', '', chunk_item[path_column]) if path_column is not None else None,
                        title=chunk_item[title_column] if title_column is not None else None,
                        createdAt=chunk_item[created_at_column] if created_at_column is not None else None,
                    ) for chunk_item in chunk
                ]
            ))
            r.raise_for_status()
            print(idx)


def main():
    parser = argparse.ArgumentParser(description='CSV to Short.cm importer', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('--secret-key', dest='secret_key', help='Your short.cm secret key', required=True)
    subparsers = parser.add_subparsers(dest="subcommand")
    subparsers.required = True
    for shortcm_subparser in shortcm_subparsers:
        shortcm_subparser.add_parser(subparsers)

    args = parser.parse_args()

    for shortcm_subparser in shortcm_subparsers:
        if args.subcommand == shortcm_subparser.subcommand:
            shortcm_subparser.run_command(args)

if __name__ == '__main__':
    main()



import requests
import re
import argparse
import csv
import progressbar
import time
import arrow

subcommand = 'csv-import'

def chunks(l, n):
    """Yield successive n-sized chunks from l."""
    for i in range(0, len(l), n):
        yield l[i:i + n]

FIELD_MAPPING={
    'originalURL': 'original_url_column',
    'createdAt': 'created_at_column',
    'title': 'title_column',
    'utmSource': 'utm_source_column',
    'utmMedium': 'utm_medium_column',
    'utmCampaign': 'utm_campaign_column',
}

def import_csv(filename, secret_key, domain, path_column, cloaking, delimiter, **kwargs):
    with open(filename) as f:
        csv_reader = csv.reader(f, delimiter=delimiter)
        lines = [line for line in csv_reader]
        links_count = len(lines)
        link_chunks = chunks(lines, 1000)
        pb = progressbar.ProgressBar(widgets=[
            progressbar.Percentage(),
            ' ',
            progressbar.Counter(),
            progressbar.Bar(),
            progressbar.AdaptiveETA()
        ], max_value=links_count)
        for idx, chunk in enumerate(link_chunks):
            link_dicts = []
            for chunk_item in chunk:
                link_dict = dict(
                    cloaking=int(cloaking),
                    path=re.sub('https?://[^/]+/', '', chunk_item[path_column]) if path_column is not None else None,
                )
                for api_param, cli_param in FIELD_MAPPING.items():
                    if kwargs.get(cli_param, None) is not None:
                        link_dict[api_param] = chunk_item[kwargs[cli_param]]
                        if api_param == "createdAt":
                            link_dict[api_param] = arrow.get(link_dict[api_param]).format()
                link_dicts.append(link_dict)
            r = requests.post('https://api.short.cm/links/bulk', headers={
                'Authorization': secret_key,
            }, json=dict(
                domain=domain,
                allowDuplicates=kwargs['allow_duplicates'],
                links=link_dicts,
            ))
            if r.status_code == 400:
                print(r.json())
                r.raise_for_status()
            r.raise_for_status()
            j = r.json()
            for link_status in j:
                if link_status.get('error'):
                    print(link_status['error'])
            pb.update(idx * 1000)
            time.sleep(1)


def add_parser(subparsers):
    import_parser = subparsers.add_parser('csv-import', help='CSV to Short.cm importer')
    import_parser.add_argument('--filename', dest='filename', help='Filename to import', required=True)
    import_parser.add_argument('--domain', dest='domain', help='Short domain', required=True)
    import_parser.add_argument('--cloaking', default=0, type=int, dest='cloaking', help='Cloaking enabled, default - disabled')
    import_parser.add_argument('--delimiter', default=',', dest='delimiter', help='CSV delimiter, by default – ,')
    import_parser.add_argument('--allow-duplicates', default=0, type=int, dest='allow_duplicates', help='Allow original URL dupilcates')
    import_parser.add_argument('--path-column', dest='path_column', help='Column number (starting from 0) for path', type=int)
    import_parser.add_argument('--original-url-column', dest='original_url_column', help='Column number (starting from 0) for original URL', required=True, type=int)
    import_parser.add_argument('--title-column', dest='title_column', help='Column number (starting from 0) for link title', type=int)
    import_parser.add_argument('--created-at-column', dest='created_at_column', help='Column number (starting from 0) for link creation date', type=int)
    import_parser.add_argument(
        '--utm-source-column', dest='utm_source_column', help='Column number (starting from 0) for link utm source', type=int)
    import_parser.add_argument(
        '--utm-medium-column', dest='utm_medium_column', help='Column number (starting from 0) for link utm medium', type=int)
    import_parser.add_argument(
        '--utm-campaign-column', dest='utm_campaign_column', help='Column number (starting from 0) for link utm medium', type=int)
    return import_parser


def run_command(args):
    import_csv(**vars(args))




import requests
import re
import argparse
import logging

logging.basicConfig(level=logging.INFO)

subcommand = 'bitly-import'

def chunks(l, n):
    """Yield successive n-sized chunks from l."""
    for i in range(0, len(l), n):
        yield l[i:i + n]

def import_bitly(bitly_key, secret_key, domain):
    pass  # TODO do bitly


def add_parser(subparsers):
    bitly_parser = subparsers.add_parser('bitly-import', help='CSV to Short.cm importer')
    bitly_parser.add_argument('--bitly-key', dest='bitly_key', help='Bitly API key', required=True)
    bitly_parser.add_argument('--domain', dest='domain', help='Short domain', required=False)
    return bitly_parser


def run_command(args):
    import_bitly(bitly_key=args.bitly_key, secret_key=args.secret_key, domain=args.domain)




#!/usr/bin/env python

from setuptools import setup

setup(name='shortcm-client',
      version='0.7.5',
      description='Short.cm commpand line UI',
      author='Andrii Kostenko',
      author_email='andrii@short.cm',
      url='https://github.com/Short-cm/shortcm-cli',
      packages=['shortcm_client'],
      long_description_content_type="text/markdown",
      long_description=open('README.md').read(),
      install_requires=['requests', 'arrow', 'progressbar2'],
      entry_points={
        'console_scripts': [
            'shortcm=shortcm_client.__main__:main',
        ]
      }
 )



import requests
import re
import argparse
import sys
import csv
import progressbar

subcommand = 'link-expand'

def link_expand(domain, path, secret_key):
    r = requests.get('https://api.short.cm/links/expand', headers={
        'Authorization': secret_key,
    }, params=dict(
        domain=domain,
        path=path
    ))
    if r.status_code == 404:
        print("Path %s not found" % path)
        return
    r.raise_for_status()
    print(r.json())


def add_parser(subparsers):
    import_parser = subparsers.add_parser('link-expand', help='Get information about link by domain and path')
    import_parser.add_argument('--domain', dest='domain', help='Short domain', required=True)
    import_parser.add_argument('--path', dest='path', help='Path part of URL', required=True)
    return import_parser


def run_command(args):
    link_expand(args.domain, args.path, args.secret_key)

